@@ -27,7 +27,7 @@ header("Content-type: text/xml");
 $feed_name = "Spodcast autofeed";
 $feed_description = "Spodcast autofeed";
 $base_url = strtok($PROTOCOL . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'], '?');
-$feed_logo = "$base_url/''' + RSS_FEED_SHOW_IMAGE r'''";
+$feed_logo = "$base_url/''' + RSS_FEED_SHOW_IMAGE + r'''";
 $feed_link = $base_url;
 $allowed_extensions = array('mp4','m4a','aac','mp3','ogg');
 
@@ -318,7 +318,7 @@ function background_run($command, $id) {
     $md5 = md5($id);
     $runfile = $md5.".json";
     $output = $md5.".log";
-    $cmd = sprintf("%s > %s 2>&1 & echo $!", $command, $output);
+    $cmd = sprintf("nohup %s > %s 2>&1 & echo $!", $command, $output);
     exec($cmd, $pid, $retval);
     if ($retval == 0 && count($pid) > 0 && $pid[0] > 0) {
         $info['command']=$command;
